<?php
/**
 * Slider Section options
 *
 * @package Theme Palace
 * @subpackage Music Freak Pro
 * @since Music Freak Pro 1.0.0
 */

// Add Slider section
$wp_customize->add_section( 'music_freak_pro_slider_section', array(
	'title'             => esc_html__( 'Main Slider','music-freak-pro' ),
	'description'       => esc_html__( 'Slider Section options.', 'music-freak-pro' ),
	'panel'             => 'music_freak_pro_front_page_panel',
) );

// Slider content enable control and setting
$wp_customize->add_setting( 'music_freak_pro_theme_options[slider_section_enable]', array(
	'default'			=> 	$options['slider_section_enable'],
	'sanitize_callback' => 'music_freak_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Music_Freak_Pro_Switch_Control( $wp_customize, 'music_freak_pro_theme_options[slider_section_enable]', array(
	'label'             => esc_html__( 'Slider Section Enable', 'music-freak-pro' ),
	'section'           => 'music_freak_pro_slider_section',
	'on_off_label' 		=> music_freak_pro_switch_options(),
) ) );

// Event social icons number control and setting
$wp_customize->add_setting( 'music_freak_pro_theme_options[slider_count]', array(
	'default'          	=> $options['slider_count'],
	'sanitize_callback' => 'music_freak_pro_sanitize_number_range',
	'validate_callback' => 'music_freak_pro_validate_slider_count',
) );

$wp_customize->add_control( 'music_freak_pro_theme_options[slider_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'music-freak-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'music-freak-pro' ),
	'section'           => 'music_freak_pro_slider_section',
	'active_callback'   => 'music_freak_pro_is_slider_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

// Slider content type control and setting
$wp_customize->add_setting( 'music_freak_pro_theme_options[slider_content_type]', array(
	'default'          	=> $options['slider_content_type'],
	'sanitize_callback' => 'music_freak_pro_sanitize_select',
) );

$wp_customize->add_control( 'music_freak_pro_theme_options[slider_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'music-freak-pro' ),
	'section'           => 'music_freak_pro_slider_section',
	'type'				=> 'select',
	'active_callback' 	=> 'music_freak_pro_is_slider_section_enable',
	'choices'			=> array(
            'page'      => esc_html__( 'Page', 'music-freak-pro' ),
            'post'      => esc_html__( 'Post', 'music-freak-pro' ),
            'category'  => esc_html__( 'Category', 'music-freak-pro' ),
        ),
) );

for ( $i = 1; $i <= $options['slider_count']; $i++ ) :
	// slider pages drop down chooser control and setting
	$wp_customize->add_setting( 'music_freak_pro_theme_options[slider_content_page_' . $i . ']', array(
		'sanitize_callback' => 'music_freak_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Music_Freak_Pro_Dropdown_Chooser( $wp_customize, 'music_freak_pro_theme_options[slider_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'music-freak-pro' ), $i ),
		'section'           => 'music_freak_pro_slider_section',
		'choices'			=> music_freak_pro_page_choices(),
		'active_callback'	=> 'music_freak_pro_is_slider_section_content_page_enable',
	) ) );

	// slider posts drop down chooser control and setting
	$wp_customize->add_setting( 'music_freak_pro_theme_options[slider_content_post_' . $i . ']', array(
		'sanitize_callback' => 'music_freak_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Music_Freak_Pro_Dropdown_Chooser( $wp_customize, 'music_freak_pro_theme_options[slider_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'music-freak-pro' ), $i ),
		'section'           => 'music_freak_pro_slider_section',
		'choices'			=> music_freak_pro_post_choices(),
		'active_callback'	=> 'music_freak_pro_is_slider_section_content_post_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'music_freak_pro_theme_options[slider_content_category]', array(
	'sanitize_callback' => 'music_freak_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Music_Freak_Pro_Dropdown_Taxonomies_Control( $wp_customize,'music_freak_pro_theme_options[slider_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'music-freak-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'music-freak-pro' ),
	'section'           => 'music_freak_pro_slider_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'music_freak_pro_is_slider_section_content_category_enable'
) ) );

// slider btn title setting and control
$wp_customize->add_setting( 'music_freak_pro_theme_options[slider_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['slider_btn_title'],
) );

$wp_customize->add_control( 'music_freak_pro_theme_options[slider_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'music-freak-pro' ),
	'section'        	=> 'music_freak_pro_slider_section',
	'active_callback' 	=> 'music_freak_pro_is_slider_section_enable',
	'type'				=> 'text',
) );

// slider alt btn title setting and control
$wp_customize->add_setting( 'music_freak_pro_theme_options[slider_alt_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['slider_alt_btn_title'],
) );

$wp_customize->add_control( 'music_freak_pro_theme_options[slider_alt_btn_title]', array(
	'label'           	=> esc_html__( 'Alt Button Label', 'music-freak-pro' ),
	'section'        	=> 'music_freak_pro_slider_section',
	'active_callback' 	=> 'music_freak_pro_is_slider_section_enable',
	'type'				=> 'text',
) );

// slider alt btn url setting and control
$wp_customize->add_setting( 'music_freak_pro_theme_options[slider_alt_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'music_freak_pro_theme_options[slider_alt_btn_url]', array(
	'label'           	=> esc_html__( 'Alt Button Url', 'music-freak-pro' ),
	'section'        	=> 'music_freak_pro_slider_section',
	'active_callback' 	=> 'music_freak_pro_is_slider_section_enable',
	'type'				=> 'url',
) );

// slider video url setting and control
$wp_customize->add_setting( 'music_freak_pro_theme_options[slider_video]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'music_freak_pro_theme_options[slider_video]', array(
	'label'           	=> esc_html__( 'Video Url', 'music-freak-pro' ),
	'description'       => esc_html__( 'Note: Supports all video sources that WordPress has mentioned in documentation.', 'music-freak-pro' ),
	'section'        	=> 'music_freak_pro_slider_section',
	'active_callback' 	=> 'music_freak_pro_is_slider_section_enable',
	'type'				=> 'url',
) );