<?php
/**
 * Testimonial Section options
 *
 * @package Theme Palace
 * @subpackage Music Freak Pro
 * @since Music Freak Pro 1.0.0
 */

// Add Testimonial section
$wp_customize->add_section( 'music_freak_pro_testimonial_section', array(
	'title'             => esc_html__( 'Testimonial','music-freak-pro' ),
	'description'       => esc_html__( 'Testimonial Section options.', 'music-freak-pro' ),
	'panel'             => 'music_freak_pro_front_page_panel',
) );

// Testimonial content enable control and setting
$wp_customize->add_setting( 'music_freak_pro_theme_options[testimonial_section_enable]', array(
	'default'			=> 	$options['testimonial_section_enable'],
	'sanitize_callback' => 'music_freak_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Music_Freak_Pro_Switch_Control( $wp_customize, 'music_freak_pro_theme_options[testimonial_section_enable]', array(
	'label'             => esc_html__( 'Testimonial Section Enable', 'music-freak-pro' ),
	'section'           => 'music_freak_pro_testimonial_section',
	'on_off_label' 		=> music_freak_pro_switch_options(),
) ) );

// testimonial image setting and control.
$wp_customize->add_setting( 'music_freak_pro_theme_options[testimonial_image]', array(
	'default'			=> $options['testimonial_image'],
	'sanitize_callback' => 'music_freak_pro_sanitize_image',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'music_freak_pro_theme_options[testimonial_image]',
		array(
		'label'       		=> esc_html__( 'Background Image', 'music-freak-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'music-freak-pro' ), 1500, 500 ),
		'section'     		=> 'music_freak_pro_testimonial_section',
		'active_callback'	=> 'music_freak_pro_is_testimonial_section_enable',
) ) );

// Event social icons number control and setting
$wp_customize->add_setting( 'music_freak_pro_theme_options[testimonial_count]', array(
	'default'          	=> $options['testimonial_count'],
	'sanitize_callback' => 'music_freak_pro_sanitize_number_range',
	'validate_callback' => 'music_freak_pro_validate_testimonial_count',
) );

$wp_customize->add_control( 'music_freak_pro_theme_options[testimonial_count]', array(
	'label'             => esc_html__( 'Number of Testimonials', 'music-freak-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'music-freak-pro' ),
	'section'           => 'music_freak_pro_testimonial_section',
	'active_callback'   => 'music_freak_pro_is_testimonial_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

// Testimonial content type control and setting
$wp_customize->add_setting( 'music_freak_pro_theme_options[testimonial_content_type]', array(
	'default'          	=> $options['testimonial_content_type'],
	'sanitize_callback' => 'music_freak_pro_sanitize_select',
) );

$wp_customize->add_control( 'music_freak_pro_theme_options[testimonial_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'music-freak-pro' ),
	'section'           => 'music_freak_pro_testimonial_section',
	'type'				=> 'select',
	'active_callback' 	=> 'music_freak_pro_is_testimonial_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'music-freak-pro' ),
		'post' 		=> esc_html__( 'Post', 'music-freak-pro' ),
		'category' 	=> esc_html__( 'Category', 'music-freak-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'music-freak-pro' ),
	),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'music_freak_pro_theme_options[testimonial_content_category]', array(
	'sanitize_callback' => 'music_freak_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Music_Freak_Pro_Dropdown_Taxonomies_Control( $wp_customize,'music_freak_pro_theme_options[testimonial_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'music-freak-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'music-freak-pro' ),
	'section'           => 'music_freak_pro_testimonial_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'music_freak_pro_is_testimonial_section_content_category_enable'
) ) );

for ( $i = 1; $i <= $options['testimonial_count']; $i++ ) :
	// testimonial pages drop down chooser control and setting
	$wp_customize->add_setting( 'music_freak_pro_theme_options[testimonial_content_page_' . $i . ']', array(
		'sanitize_callback' => 'music_freak_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Music_Freak_Pro_Dropdown_Chooser( $wp_customize, 'music_freak_pro_theme_options[testimonial_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'music-freak-pro' ), $i ),
		'section'           => 'music_freak_pro_testimonial_section',
		'choices'			=> music_freak_pro_page_choices(),
		'active_callback'	=> 'music_freak_pro_is_testimonial_section_content_page_enable',
	) ) );

	// testimonial posts drop down chooser control and setting
	$wp_customize->add_setting( 'music_freak_pro_theme_options[testimonial_content_post_' . $i . ']', array(
		'sanitize_callback' => 'music_freak_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Music_Freak_Pro_Dropdown_Chooser( $wp_customize, 'music_freak_pro_theme_options[testimonial_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'music-freak-pro' ), $i ),
		'section'           => 'music_freak_pro_testimonial_section',
		'choices'			=> music_freak_pro_post_choices(),
		'active_callback'	=> 'music_freak_pro_is_testimonial_section_content_post_enable',
	) ) );

	// testimonial title setting and control
	$wp_customize->add_setting( 'music_freak_pro_theme_options[testimonial_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'music_freak_pro_theme_options[testimonial_title_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Title %d', 'music-freak-pro' ), $i ),
		'section'        	=> 'music_freak_pro_testimonial_section',
		'active_callback' 	=> 'music_freak_pro_is_testimonial_section_content_custom_enable',
		'type'				=> 'text',
	) );

	// testimonial position setting and control
	$wp_customize->add_setting( 'music_freak_pro_theme_options[testimonial_position_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'music_freak_pro_theme_options[testimonial_position_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Position %d', 'music-freak-pro' ), $i ),
		'section'        	=> 'music_freak_pro_testimonial_section',
		'active_callback' 	=> 'music_freak_pro_is_testimonial_section_content_position_enable',
		'type'				=> 'text',
	) );

	// testimonial description setting and control
	$wp_customize->add_setting( 'music_freak_pro_theme_options[testimonial_description_' . $i . ']', array(
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( 'music_freak_pro_theme_options[testimonial_description_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Description %d', 'music-freak-pro' ), $i ),
		'section'        	=> 'music_freak_pro_testimonial_section',
		'active_callback' 	=> 'music_freak_pro_is_testimonial_section_content_custom_enable',
		'type'				=> 'textarea',
	) );

	// testimonial image setting and control.
	$wp_customize->add_setting( 'music_freak_pro_theme_options[testimonial_image_' . $i . ']', array(
		'sanitize_callback' => 'music_freak_pro_sanitize_image'
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'music_freak_pro_theme_options[testimonial_image_' . $i . ']',
			array(
			'label'       		=> sprintf( esc_html__( 'Image %d', 'music-freak-pro' ), $i ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'music-freak-pro' ), 200, 200 ),
			'section'     		=> 'music_freak_pro_testimonial_section',
			'active_callback'	=> 'music_freak_pro_is_testimonial_section_content_custom_enable',
	) ) );

	// testimonial position setting and control
	$wp_customize->add_setting( 'music_freak_pro_theme_options[testimonial_link_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'music_freak_pro_theme_options[testimonial_link_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'URL Link %d', 'music-freak-pro' ), $i ),
		'section'        	=> 'music_freak_pro_testimonial_section',
		'active_callback' 	=> 'music_freak_pro_is_testimonial_section_content_custom_enable',
		'type'				=> 'url',
	) );

	// testimonial hr setting and control
	$wp_customize->add_setting( 'music_freak_pro_theme_options[testimonial_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Music_Freak_Pro_Customize_Horizontal_Line( $wp_customize, 'music_freak_pro_theme_options[testimonial_hr_'. $i .']',
		array(
			'section'         => 'music_freak_pro_testimonial_section',
			'active_callback' => 'music_freak_pro_is_testimonial_section_content_seperator_enable',
			'type'			  => 'hr'
	) ) );
endfor;

